@@ -20,9 +20,9 @@ new("KorAPConnection", verbose = TRUE) %>%
   mutate(LVC = sprintf("[%s](%s)", example, webUIRequestUrl)) %>%
   { . ->> ca } %>%
   select(LVC, logDice, pmi, ll) %>%
-  head(50) %>%
+  slice_head(n = 50) %>%
   kable(format = "pipe", digits = 2)  %>%
   cat(file = mdFile, sep = "\n")
 
 rmarkdown::render(mdFile)
-browseURL(gsub("\\.md", ".html", mdFile))
+browseURL(str_replace(mdFile, "\\.md$", ".html"))
